#ifndef __MYLIB_HPP
#define __MYLIB_HPP

#include "builtin.hpp"
#include "mylib.hpp"

using namespace __shedskin__;
namespace __mylib__ {

extern str *const_0;




extern list<__ss_int> *arFiltertest, *arTest;
extern str *__name__;

__ss_bool IsCompiled();
list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max, __ss_int min, __ss_int limitMovement);

PyMODINIT_FUNC initmylib(void);

PyMODINIT_FUNC addmylib(void);

} // module namespace
namespace __shedskin__ { /* XXX */

}
#endif
